==> mesa-23.0.1.tar.xz: mesa-23.0.1/src/egl/main/eglentrypoint.h <==
/* core functions queryable in the presence of
 * EGL_KHR_get_all_proc_addresses or EGL 1.5
 */
/* alphabetical order */
EGL_ENTRYPOINT(eglBindAPI)
EGL_ENTRYPOINT(eglBindTexImage)
EGL_ENTRYPOINT(eglBindWaylandDisplayWL)
EGL_ENTRYPOINT(eglChooseConfig)
EGL_ENTRYPOINT(eglClientWaitSync)
EGL_ENTRYPOINT(eglClientWaitSyncKHR)
EGL_ENTRYPOINT(eglCopyBuffers)
EGL_ENTRYPOINT(eglCreateContext)
EGL_ENTRYPOINT(eglCreateDRMImageMESA)
EGL_ENTRYPOINT(eglCreateImage)
EGL_ENTRYPOINT(eglCreateImageKHR)
EGL_ENTRYPOINT(eglCreatePbufferFromClientBuffer)
EGL_ENTRYPOINT(eglCreatePbufferSurface)
EGL_ENTRYPOINT(eglCreatePixmapSurface)
EGL_ENTRYPOINT(eglCreatePlatformPixmapSurface)
EGL_ENTRYPOINT(eglCreatePlatformPixmapSurfaceEXT)
EGL_ENTRYPOINT(eglCreatePlatformWindowSurface)
EGL_ENTRYPOINT(eglCreatePlatformWindowSurfaceEXT)
EGL_ENTRYPOINT(eglCreateSync)
EGL_ENTRYPOINT(eglCreateSync64KHR)
EGL_ENTRYPOINT(eglCreateSyncKHR)
EGL_ENTRYPOINT(eglCreateWaylandBufferFromImageWL)
EGL_ENTRYPOINT(eglCreateWindowSurface)
EGL_ENTRYPOINT(eglDebugMessageControlKHR)
EGL_ENTRYPOINT(eglDestroyContext)
EGL_ENTRYPOINT(eglDestroyImage)
EGL_ENTRYPOINT(eglDestroyImageKHR)
EGL_ENTRYPOINT(eglDestroySurface)
EGL_ENTRYPOINT(eglDestroySync)
EGL_ENTRYPOINT(eglDestroySyncKHR)
EGL_ENTRYPOINT(eglDupNativeFenceFDANDROID)
EGL_ENTRYPOINT(eglExportDMABUFImageMESA)
EGL_ENTRYPOINT(eglExportDMABUFImageQueryMESA)
EGL_ENTRYPOINT(eglExportDRMImageMESA)
EGL_ENTRYPOINT(eglGetConfigAttrib)
EGL_ENTRYPOINT(eglGetConfigs)
EGL_ENTRYPOINT(eglGetCurrentContext)
EGL_ENTRYPOINT(eglGetCurrentDisplay)
EGL_ENTRYPOINT(eglGetCurrentSurface)
EGL_ENTRYPOINT(eglGetDisplay)
EGL_ENTRYPOINT(eglGetDisplayDriverConfig)
EGL_ENTRYPOINT(eglGetDisplayDriverName)
EGL_ENTRYPOINT(eglGetError)
EGL_ENTRYPOINT(eglGetMscRateANGLE)
EGL_ENTRYPOINT(eglGetPlatformDisplay)
EGL_ENTRYPOINT(eglGetPlatformDisplayEXT)
EGL_ENTRYPOINT(eglGetProcAddress)
EGL_ENTRYPOINT(eglGetSyncAttrib)
EGL_ENTRYPOINT(eglGetSyncAttribKHR)
EGL_ENTRYPOINT(eglGetSyncValuesCHROMIUM)
EGL_ENTRYPOINT(eglInitialize)
EGL_ENTRYPOINT(eglLabelObjectKHR)
EGL_ENTRYPOINT(eglMakeCurrent)
EGL_ENTRYPOINT(eglPostSubBufferNV)
EGL_ENTRYPOINT(eglQueryAPI)
EGL_ENTRYPOINT(eglQueryContext)
EGL_ENTRYPOINT(eglQueryDebugKHR)
EGL_ENTRYPOINT(eglQueryDeviceAttribEXT)
EGL_ENTRYPOINT(eglQueryDeviceStringEXT)
EGL_ENTRYPOINT(eglQueryDevicesEXT)
EGL_ENTRYPOINT(eglQueryDisplayAttribEXT)
EGL_ENTRYPOINT(eglQueryDmaBufFormatsEXT)
EGL_ENTRYPOINT(eglQueryDmaBufModifiersEXT)
EGL_ENTRYPOINT(eglQueryString)
EGL_ENTRYPOINT(eglQuerySurface)
EGL_ENTRYPOINT(eglQueryWaylandBufferWL)
EGL_ENTRYPOINT(eglReleaseTexImage)
EGL_ENTRYPOINT(eglReleaseThread)
EGL_ENTRYPOINT(eglSetBlobCacheFuncsANDROID)
EGL_ENTRYPOINT(eglSetDamageRegionKHR)
EGL_ENTRYPOINT(eglSignalSyncKHR)
EGL_ENTRYPOINT(eglSurfaceAttrib)
EGL_ENTRYPOINT(eglSwapBuffers)
EGL_ENTRYPOINT(eglSwapBuffersRegionNOK)
EGL_ENTRYPOINT(eglSwapBuffersWithDamageEXT)
EGL_ENTRYPOINT(eglSwapBuffersWithDamageKHR)
EGL_ENTRYPOINT(eglSwapInterval)
EGL_ENTRYPOINT(eglTerminate)
EGL_ENTRYPOINT(eglUnbindWaylandDisplayWL)
EGL_ENTRYPOINT(eglWaitClient)
EGL_ENTRYPOINT(eglWaitGL)
EGL_ENTRYPOINT(eglWaitNative)
EGL_ENTRYPOINT(eglWaitSync)
EGL_ENTRYPOINT(eglWaitSyncKHR)

==> mesa-25.1.3.tar.xz: mesa-25.1.3/src/egl/main/eglentrypoint.h <==
/* core functions queryable in the presence of
 * EGL_KHR_get_all_proc_addresses or EGL 1.5
 */
/* clang-format off */
/* alphabetical order */
EGL_ENTRYPOINT(eglBindAPI)
EGL_ENTRYPOINT(eglBindTexImage)
EGL_ENTRYPOINT(eglBindWaylandDisplayWL)
EGL_ENTRYPOINT(eglChooseConfig)
EGL_ENTRYPOINT(eglClientWaitSync)
EGL_ENTRYPOINT(eglClientWaitSyncKHR)
EGL_ENTRYPOINT(eglCopyBuffers)
EGL_ENTRYPOINT(eglCreateContext)
EGL_ENTRYPOINT(eglCreateDRMImageMESA)
EGL_ENTRYPOINT(eglCreateImage)
EGL_ENTRYPOINT(eglCreateImageKHR)
EGL_ENTRYPOINT(eglCreatePbufferFromClientBuffer)
EGL_ENTRYPOINT(eglCreatePbufferSurface)
EGL_ENTRYPOINT(eglCreatePixmapSurface)
EGL_ENTRYPOINT(eglCreatePlatformPixmapSurface)
EGL_ENTRYPOINT(eglCreatePlatformPixmapSurfaceEXT)
EGL_ENTRYPOINT(eglCreatePlatformWindowSurface)
EGL_ENTRYPOINT(eglCreatePlatformWindowSurfaceEXT)
EGL_ENTRYPOINT(eglCreateSync)
EGL_ENTRYPOINT(eglCreateSync64KHR)
EGL_ENTRYPOINT(eglCreateSyncKHR)
EGL_ENTRYPOINT(eglCreateWaylandBufferFromImageWL)
EGL_ENTRYPOINT(eglCreateWindowSurface)
EGL_ENTRYPOINT(eglDebugMessageControlKHR)
EGL_ENTRYPOINT(eglDestroyContext)
EGL_ENTRYPOINT(eglDestroyImage)
EGL_ENTRYPOINT(eglDestroyImageKHR)
EGL_ENTRYPOINT(eglDestroySurface)
EGL_ENTRYPOINT(eglDestroySync)
EGL_ENTRYPOINT(eglDestroySyncKHR)
EGL_ENTRYPOINT(eglDupNativeFenceFDANDROID)
EGL_ENTRYPOINT(eglExportDMABUFImageMESA)
EGL_ENTRYPOINT(eglExportDMABUFImageQueryMESA)
EGL_ENTRYPOINT(eglExportDRMImageMESA)
EGL_ENTRYPOINT2(eglGLInteropExportObjectMESA, MesaGLInteropEGLExportObject)
EGL_ENTRYPOINT2(eglGLInteropFlushObjectsMESA, MesaGLInteropEGLFlushObjects)
EGL_ENTRYPOINT2(eglGLInteropQueryDeviceInfoMESA, MesaGLInteropEGLQueryDeviceInfo)
EGL_ENTRYPOINT(eglGetConfigAttrib)
EGL_ENTRYPOINT(eglGetConfigs)
EGL_ENTRYPOINT(eglGetCurrentContext)
EGL_ENTRYPOINT(eglGetCurrentDisplay)
EGL_ENTRYPOINT(eglGetCurrentSurface)
EGL_ENTRYPOINT(eglGetDisplay)
EGL_ENTRYPOINT(eglGetDisplayDriverConfig)
EGL_ENTRYPOINT(eglGetDisplayDriverName)
EGL_ENTRYPOINT(eglGetError)
EGL_ENTRYPOINT(eglGetMscRateANGLE)
EGL_ENTRYPOINT(eglGetPlatformDisplay)
EGL_ENTRYPOINT(eglGetPlatformDisplayEXT)
EGL_ENTRYPOINT(eglGetProcAddress)
EGL_ENTRYPOINT(eglGetSyncAttrib)
EGL_ENTRYPOINT(eglGetSyncAttribKHR)
EGL_ENTRYPOINT(eglGetSyncValuesCHROMIUM)
EGL_ENTRYPOINT(eglInitialize)
EGL_ENTRYPOINT(eglLabelObjectKHR)
EGL_ENTRYPOINT(eglMakeCurrent)
EGL_ENTRYPOINT(eglQueryAPI)
EGL_ENTRYPOINT(eglQueryContext)
EGL_ENTRYPOINT(eglQueryDebugKHR)
EGL_ENTRYPOINT(eglQueryDeviceAttribEXT)
EGL_ENTRYPOINT(eglQueryDeviceStringEXT)
EGL_ENTRYPOINT(eglQueryDevicesEXT)
EGL_ENTRYPOINT(eglQueryDisplayAttribEXT)
EGL_ENTRYPOINT(eglQueryDmaBufFormatsEXT)
EGL_ENTRYPOINT(eglQueryDmaBufModifiersEXT)
EGL_ENTRYPOINT(eglQueryString)
EGL_ENTRYPOINT(eglQuerySupportedCompressionRatesEXT)
EGL_ENTRYPOINT(eglQuerySurface)
EGL_ENTRYPOINT(eglQueryWaylandBufferWL)
EGL_ENTRYPOINT(eglReleaseTexImage)
EGL_ENTRYPOINT(eglReleaseThread)
EGL_ENTRYPOINT(eglSetBlobCacheFuncsANDROID)
EGL_ENTRYPOINT(eglSetDamageRegionKHR)
EGL_ENTRYPOINT(eglSignalSyncKHR)
EGL_ENTRYPOINT(eglSurfaceAttrib)
EGL_ENTRYPOINT(eglSwapBuffers)
EGL_ENTRYPOINT(eglSwapBuffersWithDamageEXT)
EGL_ENTRYPOINT(eglSwapBuffersWithDamageKHR)
EGL_ENTRYPOINT(eglSwapInterval)
EGL_ENTRYPOINT(eglTerminate)
EGL_ENTRYPOINT(eglUnbindWaylandDisplayWL)
EGL_ENTRYPOINT(eglWaitClient)
EGL_ENTRYPOINT(eglWaitGL)
EGL_ENTRYPOINT(eglWaitNative)
EGL_ENTRYPOINT(eglWaitSync)
EGL_ENTRYPOINT(eglWaitSyncKHR)
